==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL umpan Anda tidak valid",
    "Activity feed for %1$s" : "Umpan aktivitas untuk %1$s",
    "Activity feed" : "Umpan aktivitas",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Settings have been updated." : "Pengaturan telah diperbarui",
    "Recent activity" : "Aktivitas terbaru",
    "No activities" : "Tidak ada aktivitas",
    "More activities" : "Lebih banyak aktivitas",
    "Daily activity summary for %s" : "Ringkasan aktivitas harian untuk %s",
    "All activities" : "Semua aktivitas",
    "By others" : "Oleh lainnya",
    "By you" : "Oleh Anda",
    "Activity at %s" : "Aktivitas di %s",
    "Hello %s" : "Halo %s",
    "Hello %s," : "Halo %s,",
    "There was some activity at %s" : "Ada beberapa aktivitas di %s",
    "_and %n more _::_and %n more _" : ["dan %n lainnya"],
    "Mail" : "Surat",
    "Push" : "Dorong",
    "Activity" : "Aktivitas",
    "Notifications" : "Notifikasi",
    "This application enables people to view a log of activities about them, their files or other data." : "Aplikasi ini dapat digunakan pengguna untuk melihat log aktivitas tentang mereka, file, atau data lainnya.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Aplikasi ini mengizinkan orang-orang untuk melihat tindakan berkaitan dengan berkas dan data mereka di Nextcloud.\n\t\tSetiap orang dapat mengatur pengaturan aktivitas individu mereka dalam pengaturan pribadi\n\t\tuntuk memilih aktivitas apa saja yang dikirim ke ponsel atau surel,\n\t\tatau apakah ringkasan harian dikirim setiap pagi.\n\t\tLebih banyak informasi tersedia dalam dokumentasi Aktivitas.",
    "Send email" : "Kirim email",
    "Send push notification" : "Kirim notifikasi push",
    "Activity notification configuration" : "Konfigurasi notifikasi aktivitas",
    "Today" : "Hari Ini",
    "Yesterday" : "Kemarin",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu mengatur alamat email sebelum dapat menerima email notifikasi.",
    "Send activity emails" : "Kirim surel aktivitas",
    "As soon as possible" : "Secepatnya",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "You commented" : "Anda berkomentar",
    "Message deleted by author" : "Pesan dihapus oleh penyusun",
    "Open {filename}" : "Buka {filename}",
    "in {path}" : "di {path}",
    "Home" : "Beranda",
    "Loading activities" : "Memuat aktivitas",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan peristiwa seperti penambahan, perubahan, dan berbagi",
    "No activity yet" : "Belum ada aktivitas",
    "Loading more activities" : "Memuat aktivitas lainnya",
    "No more activities." : "Tidak ada aktivitas lagi.",
    "Could not enable RSS link" : "Tidak dapat mengaktifkan tautan RSS",
    "RSS link copied to clipboard" : "Tautan RSS disalin ke papan klip",
    "Could not copy the RSS link, please copy manually:" : "Tidak dapat menyalin tautan RSS, silakan salin secara manual:",
    "Activity settings" : "Pengaturan aktivitas",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "RSS feed" : "RSS feed",
    "Copy RSS feed link" : "Salin tautan umpan RSS",
    "Personal notification settings" : "Pengaturan pemberitahuan pribadi",
    "Unable to load the activity list" : "Tidak dapat memuat daftar aktivitas.",
    "Choose for which activities you want to get an email or push notification." : "Pilih aktivitas apa yang Anda ingin dapatkan pemberitahuan surel atau pemberitahuan push.",
    "Choose for which activities you want to get a push notification." : "Pilih aktivitas apa yang Anda inginkan untuk mendapatkan pemberitahuan push.",
    "Notification" : "Notifikasi",
    "Enable notification emails" : "Aktifkan notifikasi surel",
    "Daily activity summary" : "Ringkasan aktivitas harian",
    "Send daily activity summary in the morning" : "Kirim ringkasan aktivitas harian di pagi hari.",
    "Default settings" : "Pengaturan bawaan",
    "Configure the default notification settings for new accounts." : "Konfigurasikan pengaturan notifikasi default untuk akun baru.",
    "Unable to save the settings" : "Tidak dapat menyimpan pengaturan",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat"
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL umpan Anda tidak valid",
    "Activity feed for %1$s" : "Umpan aktivitas untuk %1$s",
    "Activity feed" : "Umpan aktivitas",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Settings have been updated." : "Pengaturan telah diperbarui",
    "remote user" : "pengguna jarak jauh",
    "Recent activity" : "Aktivitas terbaru",
    "No activities" : "Tidak ada aktivitas",
    "More activities" : "Lebih banyak aktivitas",
    "Daily activity summary for %s" : "Ringkasan aktivitas harian untuk %s",
    "_and %n more…_::_and %n more…_" : ["dan %n lagi…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Anda dapat menonaktifkan email ringkasan harian di <a href=\"%s\">pengaturan</a>.",
    "You can disable daily digest emails in the settings: %s" : "Anda dapat menonaktifkan email ringkasan harian di pengaturan: %s",
    "All activities" : "Semua aktivitas",
    "By others" : "Oleh lainnya",
    "By you" : "Oleh Anda",
    "Activity at %s" : "Aktivitas di %s",
    "Hello %s" : "Halo %s",
    "Hello %s," : "Halo %s,",
    "There was some activity at %s" : "Ada beberapa aktivitas di %s",
    "_and %n more _::_and %n more _" : ["dan %n lainnya"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Anda dapat mengubah frekuensi email ini atau menonaktifkannya di <a href=\"%s\">pengaturan</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Anda dapat mengubah frekuensi email ini atau menonaktifkannya di pengaturan: %s",
    "Mail" : "Surat",
    "Push" : "Dorong",
    "Activity" : "Aktivitas",
    "Notifications" : "Notifikasi",
    "This application enables people to view a log of activities about them, their files or other data." : "Aplikasi ini dapat digunakan pengguna untuk melihat log aktivitas tentang mereka, file, atau data lainnya.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Aplikasi ini mengizinkan orang-orang untuk melihat tindakan berkaitan dengan berkas dan data mereka di Nextcloud.\n\t\tSetiap orang dapat mengatur pengaturan aktivitas individu mereka dalam pengaturan pribadi\n\t\tuntuk memilih aktivitas apa saja yang dikirim ke ponsel atau email,\n\t\tatau apakah ringkasan harian dikirim setiap pagi.\n\t\tLebih banyak informasi tersedia dalam dokumentasi Aktivitas.",
    "Send email" : "Kirim email",
    "Send push notification" : "Kirim notifikasi push",
    "Activity notification configuration" : "Konfigurasi notifikasi aktivitas",
    "Today" : "Hari Ini",
    "Yesterday" : "Kemarin",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu mengatur alamat email sebelum dapat menerima email notifikasi.",
    "Send activity emails" : "Kirim email aktivitas",
    "As soon as possible" : "Secepatnya",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "You commented" : "Anda berkomentar",
    "Message deleted by author" : "Pesan dihapus oleh penyusun",
    "Open {filename}" : "Buka {filename}",
    "in {path}" : "di {path}",
    "Home" : "Beranda",
    "Could not load activities" : "Tidak bisa memuat aktivitas",
    "Loading activities" : "Memuat aktivitas",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan peristiwa seperti penambahan, perubahan, dan berbagi",
    "No activity yet" : "Belum ada aktivitas",
    "Loading more activities" : "Memuat aktivitas lainnya",
    "No more activities." : "Tidak ada aktivitas lagi.",
    "Could not enable RSS link" : "Tidak dapat mengaktifkan tautan RSS",
    "RSS link copied to clipboard" : "Tautan RSS disalin ke papan klip",
    "Could not copy the RSS link, please copy manually:" : "Tidak dapat menyalin tautan RSS, silakan salin secara manual:",
    "Activity settings" : "Pengaturan aktivitas",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "RSS feed" : "RSS feed",
    "Copy RSS feed link" : "Salin tautan umpan RSS",
    "Personal notification settings" : "Pengaturan pemberitahuan pribadi",
    "Unable to load the activity list" : "Tidak dapat memuat daftar aktivitas.",
    "Choose for which activities you want to get an email or push notification." : "Pilih aktivitas apa yang Anda ingin dapatkan pemberitahuan email atau pemberitahuan push.",
    "Choose for which activities you want to get a push notification." : "Pilih aktivitas apa yang Anda inginkan untuk mendapatkan pemberitahuan push.",
    "Notification" : "Notifikasi",
    "Enable notification emails" : "Aktifkan notifikasi email",
    "Daily activity summary" : "Ringkasan aktivitas harian",
    "Send daily activity summary in the morning" : "Kirim ringkasan aktivitas harian di pagi hari.",
    "Default settings" : "Pengaturan bawaan",
    "Configure the default notification settings for new accounts." : "Konfigurasikan pengaturan notifikasi default untuk akun baru.",
    "Unable to save the settings" : "Tidak dapat menyimpan pengaturan",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat"
},
"nplurals=1; plural=0;");
